<?php
namespace ArchiveSiteMeta\Site\BlockLayout;

use DateTime;
use Omeka\Api\Representation\SiteRepresentation;
use Omeka\Api\Representation\SitePageRepresentation;
use Omeka\Api\Representation\SitePageBlockRepresentation;
use Omeka\Site\BlockLayout\AbstractBlockLayout;
use Laminas\View\Renderer\PhpRenderer;

use ArchiveSiteMeta\Site\BlockLayout\ContainerInterface;
use Laminas\Form\Element;
use Laminas\Form\FormElementManager;
use ArchiveSiteMeta\Form\ArchiveSiteMetaBlockForm;


class ArchiveSiteMeta extends AbstractBlockLayout
{
	/**
   * @var FormElementManager
   */
  protected $formElementManager;

  /**
   * @var array
   */
  protected $defaultSettings = [];

  protected $sitemeta_collections = "ff";

  /**
 * @param FormElementManager $formElementManager
 * @param array $defaultSettings
 */
  public function __construct(FormElementManager $formElementManager,
                              array $defaultSettings,
                              string $sitemeta_collections
                              //string $storage_dir
                              //ContainerInterface $site_settings
                              )

  {
      $this->formElementManager = $formElementManager;
      $this->defaultSettings = $defaultSettings;
      $this->sitemeta_collections = $sitemeta_collections;
      //$this->storage_dir = $storage_dir;
      //$this->services = $services;
  }

	public function getLabel() {
	   return 'Arc-hive site';
	}

	public function form(PhpRenderer $view,
                       SiteRepresentation $site,
                       SitePageRepresentation $page = null,
                       SitePageBlockRepresentation $block = null
    ) {
		$form = $this->formElementManager->get(ArchiveSiteMetaBlockForm::class);

    $collection_options = [];
    foreach ( explode("\n", $this->sitemeta_collections) as $value ) {
      $key_value = explode("=", $value);
      $key = str_replace(array("\r", "\n"), '', $key_value[1]);
      $collection_options[trim($key)] = $key_value[0];
    }

    $form->add([
			'name' => 'o:block[__blockIndex__][o:data][collection]',
      'type' => Element\Select::class,
      'options' => [
          'label' => "Collection",
					'value_options' => $collection_options,
      ],
		]);

		$data = $block
			? $block->data() + $this->defaultSettings
			: $this->defaultSettings;
		$form->setData([
			'o:block[__blockIndex__][o:data][currator]' => $data['currator'],
      'o:block[__blockIndex__][o:data][project_date]'  => $data['project_date'],
      'o:block[__blockIndex__][o:data][collection]'  => trim($data['collection']),
		]);
		$form->prepare();
    //$form->collections = $this->sitemeta_collections;

		$html = '';
    $html .= $view->blockAttachmentsForm($block);
		$html .= '<a href="#" class="collapse" aria-label="collapse"><h4>';
    $html .= $view->translate('Options'). '</h4></a>';
		$html .= '<div class="collapsible" style="padding-top:6px;">';
		$html .= $view->formCollection($form);
    $html .= '</div>';
		return $html;
    }

  	public function render(PhpRenderer $view, SitePageBlockRepresentation $block)
  	{
      if ($view->site->title() === "Collections") {
        $site = null;
      } else {
        $site = $view->site;
        $site_title = $view->site->title();
        $file_name = preg_replace( '/[^a-z0-9]+/', '-', strtolower($site_title) ).'.pdf';
        $tech_document_link = '<a href="/files/docs/'.$file_name.'">Technical documentation</a>';
      }
      $archiveSiteHelper = $view->getHelperPluginManager()->get('archiveSiteMeta');
      $collections = $archiveSiteHelper->getCollections();
      $date = new DateTime($block->dataValue('project_date'));
      return $view->partial('common/block-layout/site-meta', [
      			'artist' =>$block->dataValue('currator'),
      			'project_date' => $date->format('Y'),
      			'collection' => $collections[$block->dataValue('collection')],
            'site' => $site,
            'tech_document_link' => $tech_document_link
      		]);
  	}
}
