<?php declare(strict_types=1);
namespace ArchiveSiteMeta\View\Helper;
use Laminas\View\Helper\AbstractHelper;


/**
 * View helper to get metadata for all pages of the specified type.
 */
class ArchiveSiteMetaViewHelper extends AbstractHelper
{


    public function __construct($omekaSettings) #, $siteSettings)
    {
        $this->omekaSettings = $omekaSettings;
    }
    /**
     * Get data for all pages of the specified type in the current site.
     *
     * @param string|array $pageType
     * @return \Omeka\Api\Representation\SitePageBlockRepresentation[]
     */
    //public function __invoke($pageType)
    public function getSiteMetaValues($site)
    {
        // Check if the site page has the specified block.
        //$site = $this->currentSite();
        $pages = $site->pages();

        foreach ($pages as $page) {
            foreach ($page->blocks() as $block) {
                // A page can belong to multiple types…
                if ($block->layout() === 'archiveSiteMeta') {
                    $url = null;
                    $attachments = $block->attachments();
                    if ($attachments) {
                      $media = $attachments[0]->item()->media()[0];
                      $url = $media->primaryMedia()->thumbnailUrl('large');
                    }
                    return array(
                      "currator" => $block->dataValue('currator'),
                      "thumbnail" => $url,
                      'project_date' => $block->dataValue('project_date'),
                      'collection' => $block->dataValue('collection'),
                    );
                }
            }
        }
        return null;
    }

    public function getCollections(){
      $sitemeta_collections = $this->omekaSettings->get('sitemeta_collections');
      $collections = [];
      foreach ( explode("\n", $sitemeta_collections) as $value ) {
        if ($value == "") {
          continue;
        }
        $key_value = explode("=", str_replace(array("\r", "\n"), '', $value));
        if ($key_value) {
          $collections[trim($key_value[1])] = trim($key_value[0]);
        }
      }
      return $collections;
    }

    public function getPages()
    {
        return [];
    }

    /**
     * Get the site's meta image url.
     *
     * @param SiteRepresentation
     * @return string media url
     */
    public function getSiteImage($site)
    {
        foreach ($site->pages() as $page) {
          foreach ($page->blocks() as $block) {
            if ($block->layout() === 'archiveSiteMeta') {
              $attachments = $block->attachments();
              if ($attachments) {
                $media = $attachments[0]->item()->media()[0];
                return $media->primaryMedia()->thumbnailUrl('large');
              }
            }
          }
        }
        return null;
    }

    /**
     * Get the page's meta image url.
     *
     * @param SitePageRepresentation
     * @return string media url
     */
    /*
    public function getPageImage($page)
    {
        foreach ($page->blocks() as $block) {
            if ($block->layout() === 'archiveSiteMeta') {
              $attachments = $block->attachments();
              $media = $attachments[0]->item()->media()[0];
              return $media->primaryMedia()->thumbnailUrl('large');
            }
        }
        return $this->getSiteImage($page->site());
    }
    */

    /**
     * @return \Omeka\Api\Representation\SiteRepresentation
     */
    protected function currentSite()
    {
        $view = $this->getView();
        return isset($view->site)
            ? $view->site
            : $view->getHelperPluginManager()
                   ->get('Laminas\View\Helper\ViewModel')
                   ->getRoot()
                   ->getVariable('site');
    }
}
